<div style="text-align: center"> 
<img src="datatosk_logo.jpg" alt="Datatosk">
<h1>Datatosk</h1>
</div>

> Python library for fetching data from different sources

# Usage
Datatosk reads configuration from the `environment variables`.

## MySQL

Provide particular enviroment variables:
```
MYSQL_HOST_[SOURCE_NAME]=
MYSQL_PORT_[SOURCE_NAME]=
MYSQL_USER_[SOURCE_NAME]=
MYSQL_PASS_[SOURCE_NAME]=
MYSQL__DB_[SOURCE_NAME]=
```

## GoogleBigQuery

Provide particular enviroment variables:
```
GBQ_PROJECT_ID_[SOURCE_NAME]=
```
